A data.frame with 100 observations and 5 variables.
Details
This dataset appeared Zhang (2002) and was modeled
using the Binomial Logit-normal spatial model.
It consists of counts of the root disease Rhizoctonia root rot present
in barey plants collected at 100 locations in the Cunningham farm in the
north-west of the U.S.
The sampling consisted on pulling from the ground 15 plants at each location.
This dataset is a 100 by 4 matrix with rows $(x_i , y_i , t_i)$,
where $x_i$ are the coordinates of the i$^{th}$ sampling location,
$y_i$ is the total number of infected crown roots in the pulled plants at
$x_i$, and $t_i$ is the total number of crown roots in the pulled plants at $x_i$; see Zhang (2002) for further details.